# Constraints

| ID  | Constraint  |
|---|---|
|CON-1|User must interact with tool using CLI|
|CON-2|User must connect his LLM API for summarizer to work|
|CON-2|Tool should work inside the Git repository|

